@@ -1,27 +1,41 @@
 '''
-PyMySQL: A pure-Python drop-in replacement for MySQLdb.
+PyMySQL: A pure-Python MySQL client library.
+
+Copyright (c) 2010, 2013 PyMySQL contributors
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+THE SOFTWARE.
+
 '''
 
-VERSION = (0, 3, None)
+VERSION = (0, 6, None)
 
-from pymysql.constants import FIELD_TYPE
-from pymysql.converters import escape_dict, escape_sequence, escape_string
-from pymysql.err import Warning, Error, InterfaceError, DataError, \
+from ._compat import text_type, JYTHON, IRONPYTHON
+from .constants import FIELD_TYPE
+from .converters import escape_dict, escape_sequence, escape_string
+from .err import Warning, Error, InterfaceError, DataError, \
      DatabaseError, OperationalError, IntegrityError, InternalError, \
-     NotSupportedError, ProgrammingError
-from pymysql.times import Date, Time, Timestamp, \
+     NotSupportedError, ProgrammingError, MySQLError
+from .times import Date, Time, Timestamp, \
     DateFromTicks, TimeFromTicks, TimestampFromTicks
 
 import sys
 
-try:
-    frozenset
-except NameError:
-    from sets import ImmutableSet as frozenset
-    try:
-        from sets import BaseSet as set
-    except ImportError:
-        from sets import Set as set
 
 threadsafety = 1
 apilevel = "2.0"
@@ -61,18 +75,25 @@ ROWID     = DBAPISet()
 
 def Binary(x):
     """Return x as a binary type."""
-    return str(x)
+    if isinstance(x, text_type) and not (JYTHON or IRONPYTHON):
+        return x.encode()
+    return bytes(x)
 
 def Connect(*args, **kwargs):
     """
-    Connect to the database; see pymysql.connections.Connection.__init__() for
+    Connect to the database; see connections.Connection.__init__() for
     more information.
     """
-    from connections import Connection
+    from .connections import Connection
     return Connection(*args, **kwargs)
 
+from pymysql import connections as _orig_conn
+Connect.__doc__ = _orig_conn.Connection.__init__.__doc__ + """\nSee connections.Connection.__init__() for
+    information about defaults."""
+del _orig_conn
+
 def get_client_info():  # for MySQLdb compatibility
-  return '%s.%s.%s' % VERSION
+    return '%s.%s.%s' % VERSION
 
 connect = Connection = Connect
 
@@ -89,7 +110,7 @@ def thread_safe():
 def install_as_MySQLdb():
     """
     After this function is called, any application that imports MySQLdb or
-    _mysql will unwittingly actually use pymysql.
+    _mysql will unwittingly actually use
     """
     sys.modules["MySQLdb"] = sys.modules["_mysql"] = sys.modules["pymysql"]
 
@@ -100,9 +121,9 @@ __all__ = [
     'InterfaceError', 'InternalError', 'MySQLError', 'NULL', 'NUMBER',
     'NotSupportedError', 'DBAPISet', 'OperationalError', 'ProgrammingError',
     'ROWID', 'STRING', 'TIME', 'TIMESTAMP', 'Warning', 'apilevel', 'connect',
-    'connections', 'constants', 'converters', 'cursors', 'debug', 'escape',
+    'connections', 'constants', 'converters', 'cursors',
     'escape_dict', 'escape_sequence', 'escape_string', 'get_client_info',
-    'paramstyle', 'string_literal', 'threadsafety', 'version_info',
+    'paramstyle', 'threadsafety', 'version_info',
 
     "install_as_MySQLdb",
 
